==> aws-cdk.aws-sqs-1.166.1.tar.gz: aws-cdk.aws-sqs-1.166.1/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "aws-cdk.aws-sqs",
    "version": "1.166.1",
    "description": "The CDK Construct Library for AWS::SQS",
    "license": "Apache-2.0",
    "url": "https://github.com/aws/aws-cdk",
    "long_description_content_type": "text/markdown",
    "author": "Amazon Web Services",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/aws/aws-cdk.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "aws_cdk.aws_sqs",
        "aws_cdk.aws_sqs._jsii"
    ],
    "package_data": {
        "aws_cdk.aws_sqs._jsii": [
            "aws-sqs@1.166.1.jsii.tgz"
        ],
        "aws_cdk.aws_sqs": [
            "py.typed"
        ]
    },
    "python_requires": "~=3.7",
    "install_requires": [
        "aws-cdk.aws-cloudwatch==1.166.1",
        "aws-cdk.aws-iam==1.166.1",
        "aws-cdk.aws-kms==1.166.1",
        "aws-cdk.core==1.166.1",
        "constructs>=3.3.69, <4.0.0",
        "jsii>=1.63.0, <2.0.0",
        "publication>=0.0.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Typing :: Typed",
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved",
        "Framework :: AWS CDK",
        "Framework :: AWS CDK :: 1"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)

==> aws-cdk.aws-sqs-1.170.0.tar.gz: aws-cdk.aws-sqs-1.170.0/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "aws-cdk.aws-sqs",
    "version": "1.170.0",
    "description": "The CDK Construct Library for AWS::SQS",
    "license": "Apache-2.0",
    "url": "https://github.com/aws/aws-cdk",
    "long_description_content_type": "text/markdown",
    "author": "Amazon Web Services",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/aws/aws-cdk.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "aws_cdk.aws_sqs",
        "aws_cdk.aws_sqs._jsii"
    ],
    "package_data": {
        "aws_cdk.aws_sqs._jsii": [
            "aws-sqs@1.170.0.jsii.tgz"
        ],
        "aws_cdk.aws_sqs": [
            "py.typed"
        ]
    },
    "python_requires": "~=3.7",
    "install_requires": [
        "aws-cdk.aws-cloudwatch==1.170.0",
        "aws-cdk.aws-iam==1.170.0",
        "aws-cdk.aws-kms==1.170.0",
        "aws-cdk.core==1.170.0",
        "constructs>=3.3.69, <4.0.0",
        "jsii>=1.65.0, <2.0.0",
        "publication>=0.0.3",
        "typeguard~=2.13.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Typing :: Typed",
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved",
        "Framework :: AWS CDK",
        "Framework :: AWS CDK :: 1"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)
